import {
  __name
} from "./chunk-INDHDMU3.mjs";

// src/vue-utils.ts
import { isObject } from "@chakra-ui/utils";
import { inject, provide, isVNode, computed, ref, cloneVNode, h, reactive } from "vue";
function createContext(options = {}, defaults) {
  const {
    strict = true,
    errorMessage = "useContext: `context` is undefined. Seems you forgot to wrap component within the Provider",
    name
  } = options;
  let contextSymbol = Symbol(`${name}Symbol`);
  function Provider(payload) {
    provide(contextSymbol, payload);
  }
  __name(Provider, "Provider");
  function useContext(fallback = null) {
    const context = inject(contextSymbol, fallback);
    if (!context && strict) {
      throw new Error(errorMessage);
    }
    return context;
  }
  __name(useContext, "useContext");
  return [Provider, useContext, contextSymbol];
}
__name(createContext, "createContext");
function getValidChildren(slots) {
  var _a;
  const slotArray = ((_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)) || [];
  return slotArray.filter((child) => {
    return isVNode(child);
  });
}
__name(getValidChildren, "getValidChildren");
function withSingleton(slots, componentName, props) {
  const validChildren = getValidChildren(slots);
  if (validChildren.length > 1) {
    const errorMessage = `[${componentName}] : ${componentName} can only have one root element.`;
    console.error(errorMessage);
    throw new SyntaxError(errorMessage);
  }
  const finalSlot = cloneVNode(validChildren[0]);
  return h(finalSlot, props);
}
__name(withSingleton, "withSingleton");
function transformComposableProps(props) {
  return {
    ...props,
    context: reactive(props.context)
  };
}
__name(transformComposableProps, "transformComposableProps");
function isObjectComponent(subject) {
  const validComponentTypes = ["function", "object"];
  if (!validComponentTypes.includes(typeof subject))
    return false;
  if (isObject(subject)) {
    if (typeof (subject == null ? void 0 : subject.render) === "function" && isVNode(subject.render()))
      return true;
    else if (typeof (subject == null ? void 0 : subject.setup) === "function")
      return true;
  }
  return false;
}
__name(isObjectComponent, "isObjectComponent");
function resolveRef(r) {
  return typeof r === "function" ? computed(r) : ref(r);
}
__name(resolveRef, "resolveRef");

export {
  createContext,
  getValidChildren,
  withSingleton,
  transformComposableProps,
  isObjectComponent,
  resolveRef
};
