import * as vue from 'vue';
import { Slots, VNode, ComputedRef, Ref } from 'vue';
import { Dict } from '@chakra-ui/utils';
import { b as MaybeComputedRef, d as MaybeRef } from './dom-06ef5ebd.js';

interface CreateContextOptions {
    /**
     * If `true`, Vue will throw if context is `null` or `undefined`
     * In some cases, you might want to support nested context, so you can set it to `false`
     */
    strict?: boolean;
    /**
     * Error message to throw if the context is `undefined`
     */
    errorMessage?: string;
    /**
     * The display name of the context
     */
    name?: string;
}
type CreateContextReturn<T> = [(opts: T) => void, (fallback?: T) => T, Symbol];
/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
declare function createContext<ContextType>(options?: CreateContextOptions, defaults?: ContextType): CreateContextReturn<ContextType>;
/**
 * Gets only the valid children of a component,
 * and ignores any nullish or falsy child.
 *
 * @param slots vue slots
 *
 * see https://github.com/vuejs/vue-next/blob/HEAD/packages/runtime-core/src/helpers/renderSlot.ts
 */
declare function getValidChildren(slots: Slots | null): VNode[];
/**
 * Returns a copy of only the valid default slot
 *
 * @param slots - the slots object from the component setup
 * @param componentName component display name for thrown errors
 * @returns A VNode clone of the default slot
 */
declare function withSingleton(slots: Slots, componentName: string, props?: Dict): VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>;
/**
 * For the component composables -- takes in the props object
 * and returns the props with a reactive context object
 */
declare function transformComposableProps<T extends {
    context: object;
}>(props: T): T;
interface CouldBeObjectComponent {
    setup?: FunctionConstructor;
    render?: FunctionConstructor;
}
/** Checkes whether a provided object is a component */
declare function isObjectComponent<T extends CouldBeObjectComponent>(subject: T): boolean;
/**
 * Normalize value/ref/getter to `ref` or `computed`.
 * Adapted from @vueuse/shared
 */
declare function resolveRef<T>(r: MaybeComputedRef<T>): ComputedRef<T>;
declare function resolveRef<T>(r: MaybeRef<T>): Ref<T>;
declare function resolveRef<T>(r: T): Ref<T>;

export { CouldBeObjectComponent, CreateContextOptions, createContext, getValidChildren, isObjectComponent, resolveRef, transformComposableProps, withSingleton };
